/**
 * Copyright (c) 2000-2013 Liferay, Inc. All rights reserved.
 * 
 * This library is free software; you can redistribute it and/or modify it under the terms of the
 * GNU Lesser General Public License as published by the Free Software Foundation; either version
 * 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 */

package it.tref.liferay.mapit.map.service.impl;

import it.tref.liferay.mapit.map.NoSuchPluginPortletPreferencesException;
import it.tref.liferay.mapit.map.model.PluginPortletPreferences;
import it.tref.liferay.mapit.map.service.base.PluginPortletPreferencesLocalServiceBaseImpl;

import java.util.List;

import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portlet.PortletPreferencesFactoryUtil;

/**
 * The implementation of the plugin portlet preferences local service.
 * 
 * <p>
 * All custom service methods should be put in this class. Whenever methods are added, rerun
 * ServiceBuilder to copy their definitions into the
 * {@link it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalService} interface.
 * 
 * <p>
 * This is a local service. Methods of this service will not have security checks based on the
 * propagated JAAS credentials because this service can only be accessed from within the same VM.
 * </p>
 * 
 * @author
 * @see it.tref.liferay.mapit.map.service.base.PluginPortletPreferencesLocalServiceBaseImpl
 * @see it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalServiceUtil
 */
public class PluginPortletPreferencesLocalServiceImpl extends PluginPortletPreferencesLocalServiceBaseImpl {
  /*
   * NOTE FOR DEVELOPERS:
   * 
   * Never reference this interface directly. Always use {@link
   * it.tref.liferay.mapit.map.service.PluginPortletPreferencesLocalServiceUtil} to access the
   * plugin portlet preferences local service.
   */

  public PluginPortletPreferences updatePreferences(long ownerId, int ownerType, long plid, String portletId,
      String plugin, javax.portlet.PortletPreferences portletPreferences) throws SystemException {

    String xml = PortletPreferencesFactoryUtil.toXML(portletPreferences);

    return updatePreferences(ownerId, ownerType, plid, portletId, plugin, xml);
  }

  public PluginPortletPreferences updatePreferences(long ownerId, int ownerType, long plid, String portletId,
      String plugin, String xml) throws SystemException {

    PluginPortletPreferences portletPreferences =
        pluginPortletPreferencesPersistence.fetchByO_O_P_P_P(ownerId, ownerType, plid, portletId, plugin);

    if (portletPreferences == null) {

      portletPreferences =
          pluginPortletPreferencesPersistence.create(counterLocalService.increment(PluginPortletPreferences.class
              .getName()));

      portletPreferences.setOwnerId(ownerId);
      portletPreferences.setOwnerType(ownerType);
      portletPreferences.setPlid(plid);
      portletPreferences.setPortletId(portletId);
      portletPreferences.setPlugin(plugin);
    }

    portletPreferences.setPreferences(xml);

    pluginPortletPreferencesPersistence.update(portletPreferences);

    return portletPreferences;
  }

  public List<PluginPortletPreferences> getPortletPreferences(int ownerType, long plid, String portletId, int start,
      int end) throws SystemException {

    return pluginPortletPreferencesPersistence.findByO_P_P(ownerType, plid, portletId, start, end);
  }

  public PluginPortletPreferences getPortletPreferences(long ownerId, int ownerType, long plid, String portletId,
      String plugin) throws PortalException, SystemException {

    PluginPortletPreferences portletPreferences =
        pluginPortletPreferencesPersistence.fetchByO_O_P_P_P(ownerId, ownerType, plid, portletId, plugin);

    if (portletPreferences == null) {
      throw new NoSuchPluginPortletPreferencesException();
    }

    return portletPreferences;
  }

  public javax.portlet.PortletPreferences getPreferences(long companyId, long ownerId, int ownerType, long plid,
      String portletId, String plugin) throws SystemException, PortalException {

    PluginPortletPreferences portletPreferences =
        pluginPortletPreferencesPersistence.fetchByO_O_P_P_P(ownerId, ownerType, plid, portletId, plugin);

    if (portletPreferences == null) {
      throw new NoSuchPluginPortletPreferencesException();
    }

    return PortletPreferencesFactoryUtil.fromXML(companyId, ownerId, ownerType, plid, portletId,
        portletPreferences.getPreferences());
  }
}
